<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>MainWindow</name>
    <message>
        <source>Up</source>
        <translation>Su</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Imposta</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Completato</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Info programma</translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>URL playlist:</translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>Nome engine</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>Opzioni generali</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Libreria</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Opzioni download</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Nome engine:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>Opzioni download:</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>Filtro URL</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Ottieni opzioni elenco:</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Risoluzione</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>Seleziona lingua</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Codice formato</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>URL da scaricare</translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>Ripristina opzioni a valori predefiniti</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>Opzioni predefinite engine</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>Incolla contenuto Appunti</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>Downloader playlist</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Abbonamenti</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Estensioni</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>Usati recentemente</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>Nome UI</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>Cartella download</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Miniatura</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>URL (download):</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>Ottieni elenco</translation>
    </message>
    <message>
        <source>Basic Downloader</source>
        <translation>Downloader base</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>Aggiungi URL ad elenco</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Imposta predefiniti</translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>Downloader batch</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Opzioni profilo</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>Imposta quale URL deve essere gestita da quale motore</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation>Incolla URL dagli Appunti</translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>Monitora Appunti per URL</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>Visualizza icona barra sistema</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>Elenco salvataggio automatico media non scaricati</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>Azzera file archivio interno</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>Usa file archivio interno</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>Opzioni da aggiungere</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>Gestione URL</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation>Imposta opzioni download</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Codifica testo</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Nascondi</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation>Intervallo di tempo orario inizio (oo:mm:ss):</translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation>Intervallo di tempo orario fine (oo:mm:ss):</translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation>Capitoli (separati da virgola):</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Dividi per capitoli</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Sito web</translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation>Numero massimo download simultanei</translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation>Al termine nascondi automaticamente download</translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation>Impostazioni proxy</translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation>Usa configurazione proxy manuale</translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation>Ottieni la configurazione proxy dal sistema</translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation>Nessun proxy</translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation>Configurazione manuale proxy
Esempio 1: 192.168.93.89:8080
Esempio 2: ${gateway}:8080</translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation>Usa configurazione proxy di sistema</translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation>Visualizza info versione e aggiornamenti download automatico</translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation>Visualizza info versione attuale e più recente</translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation>Visualizza info solo sulla versione</translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation>Non fare nulla</translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation>Azioni all&apos;avvio del programma</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Dim. file</translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>Abilita scheda Libreria</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation>Riproduci i contenuti multimediali scaricati</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation>Inserisci l&apos;URLplaylist. 
Per aggiungere più playlist, separale con uno spazio o una nuova riga</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Rinomina il file qui sotto il testo</translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation>Un pulsante per aprire una cartella da usare come cartella di download</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation>Un pulsante per aprire una cartella in cui sono archiviati i file di configurazione tema</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation>Un pulsante per aprire una cartella in cui sono archiviati i file binari dell&apos;estensione</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation>Sei sicuro di voler reimpostare queste opzioni ai valori predefiniti?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation>Nome del browser web usato per ottenere i cookie</translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation>Interfaccia (richiede riavvio)</translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation>Switch tra il nome del browser ed il percorso del file cookie</translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation>Visualizza metadati in downloader batch</translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation>Download automatico elementi aggiunti in downloader batch</translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation>Notifica a download completato</translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation>Notifica quando tutti i download sono stati completati</translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation>Opzioni engine</translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation>Estensioni</translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation>Rimuovi un&apos;estensione</translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation>Aggiorna un&apos;estensione</translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation>Aggiungi un&apos;estensione</translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation>Apri cartella eseguibile</translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation>Apri cartella estensione</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Destination</source>
        <translation>Destinazione</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation>Russo (Russia)</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Azzera</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>Forza download</translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>Salva elenco in un file</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>Ottieni elenco da file</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>Versione rilevata</translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation>Francese (Francia)</translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>Media già in archivio</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>L&quot;engine &quot;%1&quot; richiede almeno la versione &quot;%2&quot; di Media Downloader</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>Errore nel download. Impossibile creare questo percorso: </translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>Rispondi a</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Opzioni download</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>Visualizza finestra registro eventi</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>Data upload:</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Nome engine:</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>Post elaborazione</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>2. Vai alla scheda &quot;Opzioni generali&quot;.</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation>Giapponese (Giappone)</translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>Avvia download</translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>Errore, eseguibile backend &quot;%1&quot; non trovato</translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>Download annullato</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>Download completato</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation>Spagnolo (Spagna)</translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation>Polacco (Polonia)</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>Impossibile trovare l&apos;eseguibile &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>Download completato</translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>Non è stato possibile trovare le informazioni sulla versione, assicurati che &quot;%1&quot; è installato e funziona correttamente</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>Apri cartella download</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Durata:</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>Impossibile aprire il file in scrittura</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>Per disabilitare questi controlli, procedi come segue:-</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>Impossibile analizzare il file json da Github</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation>Turco (Turchia)</translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>Elaborazione</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>Ripristino valore predefinito cartella download</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>Impossibile trovare l&apos;eseguibile python3 per il backend &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>Tempo trascorso:</translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>Download fallito</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>1. Vai alla scheda &quot;Impostazioni&quot;.</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation>Cinese (Cina)</translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation>Inglese (Stati Uniti)</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Opzioni profilo</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>Impossibile aprire il file in lettura</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>Impossibile caricare un plugin</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>Salva sottotitolo nel file</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>Estrazione archivio: </translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Tema scuro</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>Nome sottotitolo</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation>Italiano (Italia)</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>Versione Qt</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation>Questo programma è un software gratuito. 
Puoi ridistribuirlo e/o modificarlo secondo i termini della GNU (General Public License) pubblicata dalla Free Software Foundation; la versione 2 della Licenza o (a scelta) qualsiasi versione successiva.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translation>Questo programma è distribuito nella speranza che possa essere utile, ma SENZA ALCUNA GARANZIA; senza nemmeno la garanzia implicita di COMMERCIABILITÀ o IDONEITÀ PER UNO SCOPO PARTICOLARE.
Per maggiori dettagli vedi la GNU (General Public License).</translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>Errore, analisi file di configurazione &quot;%1&quot; fallita</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Codice formato</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Estensioni</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Risoluzione</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metodo</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation>Svedese (Svezia)</translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>La rete non ha risposto entro %1 secondi</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation>Tedesco (Germania)</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>Intervallo tempo download</translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation>Il nome file con estensione &quot;.txt&quot; salverà solo gli URL</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>Opzioni extra download</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation>Tempo rimanente</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Scaricati</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation>Velocità:</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Questo potrebbe richiedere molto tempo</translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation>Versione disponibile %1, in aggiornamento</translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation>Download non riuscito, engine bloccato</translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation>Aggiorna &quot;%1&quot; almeno alla versione &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation>Il formato richiesto non è disponibile</translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation>URL inserita non valida</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>Portoghese (Brasile)</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation>Download capitoli</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Dividi per capitoli</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation>Codice errore</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation>Si è verificato un errore di rete</translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation>Errore nell&apos;estrazione</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation>Aggiornamento completato, riavvia per usare la nuova versione</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>File non trovato</translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation>Olandese (Paesi Bassi)</translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation>Controllo versione installata di %1</translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation>Versione rilevata: %1</translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation>%1 già scaricato</translation>
    </message>
    <message>
        <source>%1 Preset Options</source>
        <translation>Opzioni preimpostate %1</translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation>Solo audio migliore disponibile</translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation>Solo audio migliore disponibile (MP3)</translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation>Audio video migliore disponibile</translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation>Audio migliore con risoluzione video %1</translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation>La URL non è supportata</translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation>Impossibile trovare l&apos;eseguibile &quot;bsdtar.exe&quot;</translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation>Esegui in modo portatile</translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation>Esegui in modo installazione</translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation>Percorso download: %1</translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation>Percorso dati app: %1</translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation>Impossibile aprire il percorso in scrittura: %1</translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation>Nascondi riga</translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation>Visualizza tutte le righe nascoste</translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation>Impostazione indirizzo server proxy a %1</translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation>Indirizzo proxy non impostato</translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation>Download non riuscito, impossibile avviare l&apos;engine</translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation>Avviso: salto contenuto appunti</translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation>Pagina web progetto</translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation>Visualizza prima le cartelle</translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation>Disponi in ordine crescente</translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation>Ordina per data</translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation>Ordina per nome</translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation>Disponi in ordine decrescente</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation>Nessun filtro</translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation>3. Fai clic sul menu &quot;Azioni all&apos;avvio del programma&quot;.</translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation>4. Seleziona &quot;Non fare nulla&quot;.</translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation>È disponibile un aggiornamento di %1</translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation>Versione più recente: %1</translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation>Impossibile avviare l&apos;eseguibile %1</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Copia URL</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation>Apri URL con %1</translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation>Copia URL %1</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation>Canale sicuro di Windows</translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation>Problemi in vista, impossibile eliminare la cartella: %1</translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation>Altri siti web</translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation>Estrai audio</translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation>Estrai audio come MP3</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Arabo</translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation>Solo miglior audio disponibile+miniatura</translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation>YouTube</translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation>Aggiornamento automatico disabilitato per %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation>La versione più recente è %1, aggiornamento automatico disabilitato</translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation>Autore: %1</translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation>N. mi piace: %1</translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation>Coreano (Corea)</translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation>Accedi per confermare che non sei un bot</translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation>Visualizza/nascondi controlli</translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation>Unione audio e video</translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation>Remux video</translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation>Greco (Grecia)</translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation>Predefinito sistema</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Chiaro</translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation>Impossibile rinominare</translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation>Completati: %1, in esecuzione: %2, non avviati: %3, completati: %4, falliti: %5, annullati: %6</translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation>Arresto in corso perché i media sono già nei file archivio</translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation>Bulgaro (Bulgaria)</translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation>Apri URL con %2</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>Riproduttore predefinito</translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation>Attenzione, nulla è stato scaricato</translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation>Download annullato, in questa scheda non sono consentiti gli URL playlist</translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation>Download annullato perché una condizione non è stata soddisfatta</translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation>Download fallito, ragione sconosciuta</translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation>Download fallito, problema di rete</translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation>Ucraino (Ucraina)</translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>Rinomina di &quot;%1&quot; in &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation>Rinomina fallita: %3</translation>
    </message>
    <message>
        <source>Skipping Checking Download Hash</source>
        <translation>Salta controllo hash download</translation>
    </message>
    <message>
        <source>Ignoring Download Because Hashes Do Not Match</source>
        <translation>Download saltato perché gli hash non corrispondono</translation>
    </message>
    <message>
        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
        <translation>Previsto &quot;%1&quot;, ottenuto &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Failed To Remove</source>
        <translation>Impossibile effettuare la rimozione</translation>
    </message>
    <message>
        <source>Renaming file to: %1</source>
        <translation>Rinomina file in: %1</translation>
    </message>
    <message>
        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
        <translation>Ignora controllo informazioni versione per il motore &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar&quot; or &quot;unzip&quot; Executable</source>
        <translation>Impossibile trovare l&apos;eseguibile &quot;bsdtar&quot; o &quot;unzip&quot;</translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation>Nascondi elenco</translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set</source>
        <translation>Imposta</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>Visualizza opzioni media</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <source>Set Batch File</source>
        <translation>Imposta file batch</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Copia URL</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Visualizza commenti</translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>Download commenti</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>Visualizza sottotitoli</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>Download sottotitoli</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>Scarica parte multimediale</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation>Ordina per data crescente</translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation>Ordina per data decrescente</translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation>Ordina per n. Mi piace</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set Download Folder</source>
        <translation>Imposta cartella download</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>Seleziona un file engine</translation>
    </message>
    <message>
        <source>Set As Default</source>
        <translation>Imposta come predefinito</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Imposta predefiniti</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation>Seleziona un file cookie</translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation>Nome del browser web per ottenere i cookie</translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation>Imposta percorso file cookie</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Elimina tutto</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation>Sei sicuro di voler eliminare il file indicato qui sotto?</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation>Sei sicuro di voler eliminare la cartella indicate qui sotto?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation>Sei sicuro di voler eliminare tutti i file e le cartelle?</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Rinomina il file qui sotto il testo</translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation>Rinomina la cartella qui sotto il testo</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation>Vuoi eliminare gli elementi selezionati?</translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Clear</source>
        <translation>Azzera</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Log Window</source>
        <translation>Finestra registro eventi</translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>Gestisci abbonamenti</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>N. pagine scaricate</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Ottieni opzioni elenco:</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>Visualizza tutti gli aggiornamenti</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Copia URL</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>Scarica tutti gli aggiornamenti</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Visualizza tutti i commenti</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Questo potrebbe richiedere molto tempo</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>Download info video</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation>Nascondi controlli</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation>Visualizza controlli</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Nascondi</translation>
    </message>
</context>
</TS>
